@@ -567,15 +567,26 @@ class FeaturesAssembler(AbstractAssembler):
                 features = ret
                 predictor_names = strats
 
-        print('saved files')
+        print('saving files')
+
+        shortcut_features = df_ret[shortcut_features_names].values
+        print('number of nan/infinity shortcut features')
+        print(np.isnan(shortcut_features).sum(axis=0).sum())
+        print(np.isinf(shortcut_features).sum(axis=0).sum())
+
         print('number of nan/infinity features')
         print(np.isnan(features).sum(axis=0).sum())
         print(np.isinf(features).sum(axis=0).sum())
+        if np.isnan(features).sum(axis=0).sum() > 0:
+            raise Exception('nan values for assembled features')
+        if np.isinf(features).sum(axis=0).sum() > 0:
+            raise Exception('inf values for assembled features')
+
         if np.isnan(features).sum(axis=0).sum() > 0:
             raise Exception('nan values for assembled features')
         if np.isinf(features).sum(axis=0).sum() > 0:
             raise Exception('inf values for assembled features')
         print('final size saved '+str(features.shape))
-        self.dbx.local_features_npy_save_and_upload(starting_date = self.starting_date,ending_date = self.running_date, features = features,features_names= predictor_names,feature_type=feature_type, n_past_features = n_past_features , local_root_directory= self.local_root_directory, user = self.user, features_saving_suffix=self.features_saving_suffix, features_names_saving_suffix=self.features_names_saving_suffix)
+        self.dbx.local_features_npy_save_and_upload(starting_date = self.starting_date,ending_date = self.running_date, shortcut_features=shortcut_features, features = features,features_names= predictor_names,feature_type=feature_type, n_past_features = n_past_features , local_root_directory= self.local_root_directory, user = self.user, features_saving_suffix=self.features_saving_suffix, features_names_saving_suffix=self.features_names_saving_suffix)
 
 
