@@ -18,6 +18,8 @@ def compute_correlation(col_one, col_two):
 def is_signal_continuum(signal_type):
     if signal_type in continuum_signals:
         return True
+    else:
+        return False
 
 def alpha_2(data = None,  contravariant = -1., **kwargs):
     data['log_vol'] = np.log(data['volumefrom'])
